leaftools.Leaf
==============

.. abjad-lineage:: abjad.tools.leaftools.Leaf.Leaf.Leaf

.. autoclass:: abjad.tools.leaftools.Leaf.Leaf.Leaf
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.descendants
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.leaf_index
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.lineage
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.override
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.parent
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.parentage
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.prolation
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.set
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.spanners
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.start_offset
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.storage_format
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.timespan
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_duration
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_nonsemantic
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__and__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__eq__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__ge__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__gt__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__le__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__lt__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__mul__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__ne__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__or__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__repr__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__rmul__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__str__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__sub__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__xor__
   :noindex:
